pub enum LivePlacementSite {
Coroutine,
Thread,
HostCallback,
Process,
}Expand description
Local placement sites supported by the live audio graph backbone.
Variants
Coroutine
Runs inline on the caller (cooperative coroutine).
Thread
Runs on a dedicated worker thread.
HostCallback
Runs directly in the host audio callback (realtime, audio-clock thread).
Process
Runs in a separate process behind shared rings.
Implementations
Sourceimpl LivePlacementSite
impl LivePlacementSite
Sourcepub const fn runs_on_audio_clock_thread(self) -> bool
pub const fn runs_on_audio_clock_thread(self) -> bool
Returns whether this site runs on the audio-clock thread.
Sourcepub const fn uses_process_ring(self) -> bool
pub const fn uses_process_ring(self) -> bool
Returns whether this site communicates over a shared process ring.
Sourcepub const fn allows_realtime_pin(self) -> bool
pub const fn allows_realtime_pin(self) -> bool
Returns whether realtime-pinned processors may run at this site.