pub struct LivePlacementSnapshot { /* private fields */ }Expand description
Capacity snapshot for a placed live node.
Implementations
Sourceimpl LivePlacementSnapshot
impl LivePlacementSnapshot
Sourcepub fn site(&self) -> LivePlacementSite
pub fn site(&self) -> LivePlacementSite
Returns the placement site captured by the snapshot.
Sourcepub fn runner(&self) -> &LiveSteadyStateSnapshot
pub fn runner(&self) -> &LiveSteadyStateSnapshot
Returns the runner’s steady-state capacity snapshot.
Sourcepub fn process_request_ring(&self) -> Option<ProcessRingSnapshot>
pub fn process_request_ring(&self) -> Option<ProcessRingSnapshot>
Returns the request ring snapshot, if this site uses a process ring.
Sourcepub fn process_response_ring(&self) -> Option<ProcessRingSnapshot>
pub fn process_response_ring(&self) -> Option<ProcessRingSnapshot>
Returns the response ring snapshot, if this site uses a process ring.