pub struct LiveProcessReport { /* private fields */ }Expand description
Process result for one live callback.
Implementations
Sourceimpl LiveProcessReport
impl LiveProcessReport
Sourcepub fn control_events(self) -> usize
pub fn control_events(self) -> usize
Returns the number of control events applied this block.
Sourcepub fn dropped_control_events(self) -> u64
pub fn dropped_control_events(self) -> u64
Returns the number of control events dropped before this block.