pub type ControlToAudioQueue = BoundedLiveQueue<LiveControlEvent>;Expand description
Bounded queue carrying control events into the audio callback.
Aliased Type
pub struct ControlToAudioQueue { /* private fields */ }pub type ControlToAudioQueue = BoundedLiveQueue<LiveControlEvent>;Bounded queue carrying control events into the audio callback.
pub struct ControlToAudioQueue { /* private fields */ }